==> nguyenpanda-0.1.8.5.tar.gz: nguyenpanda-0.1.8.5/README.md <==
# 🐼nguyenpanda🐼

[![PyPI version](https://badge.fury.io/py/nguyenpanda.svg)](https://badge.fury.io/py/nguyenpanda)
[![License: MIT](https://img.shields.io/badge/License-MIT-yellow.svg)](https://opensource.org/licenses/MIT)

## `nguyenpanda` Overview

Welcome to the world of **nguyenpanda**, a Python library that brings you the essence of utility packages, 
each named after animals, perfectly representing its unique domain.

## 🦋 butterfly

Embark on a journey through randomness and chaos with the enigmatic **_butterfly_** package.
Delve into the realms of uncertainty, probability, and statistics.
Embrace the unpredictable nature of nguyenpanda's **_butterfly_**.
Remember, even the flutter of a **_butterfly's_** wings can cause significant changes in a complex system, 
so seize the opportunity to explore its mysteries.

## 🦉 owl

Illuminate the path to mathematical enlightenment with the wisdom of the **_owl_**.
Ascend to mastery in calculus, conquer the realms of linear algebra,
and traverse the diverse landscapes of mathematics.
Allow nguyenpanda's **_owl_** to be your steadfast companion on your intellectual odyssey.

## 🐦‍⬛ raven
Enter the realm of the raven, where intelligence and innovation
converge in a comprehensive library of data structures
Inspired by the ingenuity of the raven, this package offers elegant data structures classes.

## 🦢 swan

Indulge in the beauty of aesthetics and user interfaces with the elegant **swan** package. 
Dive into the world of colors, front-end development, GUI, and more. 
Transform your applications into visual masterpieces with **_swan_**.

## Installation

To embark on your nguyenpanda adventure, install the library with the following command:
```bash
pip install nguyenpanda
```

For a specific version, gracefully flutter to your desired release with:
```bash
pip install nguyenpanda==<version>
```

## Getting Started

Unleash the power of nguyenpanda by delving into the documentation and perusing code examples within each package directory. Witness the harmonious convergence of butterfly, owl, and swan as they elevate your projects in distinct domains.

## 🤝 Contributions

Become a part of the nguyenpanda community! Share your ideas, report bugs, or request features through GitHub issues. We welcome your contributions and enhancements.

## 🪪 License

nguyenpanda is released under the MIT License. Feel the freedom to explore, utilize, and contribute, respecting the terms outlined in the license.

## ☎️ Contact

**Hà Tường Nguyên (Mr.)**  
**Computer Science**  
<small>Office for International Study Programs | HCMC University of Technology</small>


**Contact via:**  
- **Gmail:** nguyen.hatuong0107@hcmut.edu.vn
- **Gmail:** hatuongnguyen0107@gmail.com


Happy coding with nguyenpanda! 🚀

==> nguyenpanda-0.1.9.tar.gz: nguyenpanda-0.1.9/README.md <==
# 🐼nguyenpanda🐼

[![PyPI version](https://badge.fury.io/py/nguyenpanda.svg)](https://badge.fury.io/py/nguyenpanda)
[![License: MIT](https://img.shields.io/badge/License-MIT-yellow.svg)](https://opensource.org/licenses/MIT)

## `nguyenpanda` Overview

Welcome to the world of **nguyenpanda**, a Python library that brings you the essence of utility packages, 
each named after animals, perfectly representing its unique domain.

## 🦋 `butterfly`

Embark on a journey through randomness and chaos with the enigmatic **_butterfly_** package.
Delve into the realms of uncertainty, probability, and statistics.
Embrace the unpredictable nature of nguyenpanda's **_butterfly_**.
Remember, even the flutter of a **_butterfly's_** wings can cause significant changes in a complex system, 
so seize the opportunity to explore its mysteries.

## 🐦‍⬛ `crow`

**_Crow_** is a utility package designed to streamline the process of working
on Machine Learning (ML) and Deep Learning (DL) projects within Jupyter notebooks.
It provides a set of convenient functions to help manage datasets, directories,
and other common tasks that are essential in a typical ML/DL workflow.

## 🦉 `owl`

Illuminate the path to mathematical enlightenment with the wisdom of the **_owl_**.
Ascend to mastery in calculus, conquer the realms of linear algebra,
and traverse the diverse landscapes of mathematics.
Allow nguyenpanda's **_owl_** to be your steadfast companion on your intellectual odyssey.

## 🐦‍⬛ `raven`
Enter the realm of the raven, where intelligence and innovation
converge in a comprehensive library of data structures
Inspired by the ingenuity of the raven, this package offers elegant data structures classes.

## 🦢 `swan`

Indulge in the beauty of aesthetics and user interfaces with the elegant **swan** package. 
Dive into the world of colors, front-end development, GUI, and more. 
Transform your applications into visual masterpieces with **_swan_**.

## Installation

To embark on your nguyenpanda adventure, install the library with the following command:
```bash
pip install nguyenpanda
```

For a specific version, gracefully flutter to your desired release with:
```bash
pip install nguyenpanda==<version>
```

## Getting Started

Unleash the power of nguyenpanda by delving into the documentation and perusing code examples within each package directory. Witness the harmonious convergence of butterfly, owl, and swan as they elevate your projects in distinct domains.

## 🤝 Contributions

Become a part of the nguyenpanda community! Share your ideas, report bugs, or request features through GitHub issues. We welcome your contributions and enhancements.

## 🪪 License

nguyenpanda is released under the MIT License. Feel the freedom to explore, utilize, and contribute, respecting the terms outlined in the license.

## ☎️ Contact

**Hà Tường Nguyên (Mr.)**  
**Computer Science**  
<small>Office for International Study Programs | HCMC University of Technology</small>


**Contact via:**  
- **Gmail:** nguyen.hatuong0107@hcmut.edu.vn
- **Gmail:** hatuongnguyen0107@gmail.com


Happy coding with nguyenpanda! 🚀
